"""
hypixel.constants
~~~~~~~~~~~~~~~~~~~

A module for storing constant data.

(c) 2021-present duhby
MIT License, see LICENSE for more details.
"""

from .aliases import *
from .game_types import *
from .color_types import *
